@@ -1770,7 +1770,12 @@ main (int   argc,
   g_test_add_func ("/context/add", add_test1);
 
   /* Test parsing empty args */
+#if 0
+  /* This test relies on being able to call g_set_prgname() more
+   * than once.
+   */
   g_test_add_func ("/context/empty1", empty_test1);
+#endif
   g_test_add_func ("/context/empty2", empty_test2);
   g_test_add_func ("/context/empty3", empty_test3);
 
